%define snortroot /var/chroot/snort
Summary: packet-sniffer/logger
Name: snort
Version: 1.7
Release: 1.0.7
Copyright: GPL
Group: Applications/Internet
Source0: http://www.snort.org/Files/%{name}-%{version}.tar.gz
Source1: snort-stat
Source2: snortlog
Source4: snortd
Source5: snort.conf.dist
Source6: snort-rules-010801.tar.gz
Source7: vision.conf
Url: http://www.snort.org
BuildRoot: /var/tmp/%{name}-root
Packager: Henri Gomez <gomez@slib.fr>, William Stearns <wstearns@pobox.com>, and Dave Wreski <dave@linuxsecurity.com>, Wim Vandersmissen <wim@bofh.be>
Requires: libpcap >= 0.4
BuildRequires: libpcap >= 0.4

%description
Snort is a libpcap-based packet sniffer/logger which 
can be used as a lightweight network intrusion detection system. 
It features rules based logging and can perform protocol analysis, 
content searching/matching and can be used to detect a variety of 
attacks and probes, such as buffer overflows, stealth port scans, 
CGI attacks, SMB probes, OS fingerprinting attempts, and much more. 
Snort has a real-time alerting capabilty, with alerts being sent to syslog, 
a seperate "alert" file, or as a WinPopup message via Samba's smbclient


%prep
%setup -q 

%build
CFLAGS="$RPM_OPT_FLAGS" \
./configure --prefix=%snortroot --bindir=%snortroot/sbin \
	--sysconfdir=%snortroot/etc --enable-smbalerts \
        --mandir=%{_mandir}
make

%install
if [ "$RPM_BUILD_ROOT" = "/var/tmp/snort-root" ]; then
	rm -rf $RPM_BUILD_ROOT
	mkdir -p $RPM_BUILD_ROOT/%snortroot/bin
	mkdir -p $RPM_BUILD_ROOT/%snortroot/sbin
	mkdir -p $RPM_BUILD_ROOT/%snortroot/doc
	mkdir -p $RPM_BUILD_ROOT/%snortroot/etc
	mkdir -p $RPM_BUILD_ROOT/%snortroot/log/archive
	mkdir -p $RPM_BUILD_ROOT/etc/init.d
	make prefix=$RPM_BUILD_ROOT/%snortroot \
		bindir=$RPM_BUILD_ROOT/%snortroot/sbin \
		sysconfdir=$RPM_BUILD_ROOT/%snortroot/etc \
		mandir=$RPM_BUILD_ROOT/%{_mandir} install
	tar -zxf %{SOURCE6} -C $RPM_BUILD_ROOT/%snortroot/etc
	install %{SOURCE1} $RPM_BUILD_ROOT/%snortroot/bin
	install %{SOURCE2} $RPM_BUILD_ROOT/%snortroot/bin
	install %{SOURCE4} $RPM_BUILD_ROOT/etc/init.d
	install %{SOURCE7} $RPM_BUILD_ROOT/%snortroot/etc
	touch $RPM_BUILD_ROOT/%snortroot/etc/snort.conf
else
	echo Invalid Build root
	exit 1
fi

%clean
if [ "$RPM_BUILD_ROOT" = "/var/tmp/snort-root" ]; then
	rm -rf $RPM_BUILD_ROOT
else
	echo Invalid Build root
	exit 1
fi

%post
### Don't do all this stuff if we are upgrading
if [ $1 = 1 ] ; then
  useradd -M -r -d %snortroot -s /bin/false -c "Snort User" snort \
	2> /dev/null || true
  groupadd -r snort 2> /dev/null || true
fi

### This should work on anything :) -rwm
perl -e '($int_ip, $int_nm) = (`/sbin/ifconfig eth0` =~ m/addr\:([0-9\.]+)\s+.*Mask\:([0-9\.]+)/);
open(f,"/etc/resolv.conf");
while(<f>){if (/nameserver(.*)/) {$dns  = $1;$dns  =~ s/[ ]+//g; 
$dns .= "\/32 ",; push(@dns,$dns);}} close(f);
$dns[$#dns]=~s/\ //g; $dns[$#dns]=~s/,$//g;
open(f,">%snortroot/etc/snort.conf");
print f "var INTERNAL $int_ip/$int_nm\n";
print f "var EXTERNAL any\n";
print f "var DNS_SERVERS ";
foreach (@dns) {print f "$_";}
print f "\n";
print f "\npreprocessor http_decode: 80 8080\npreprocessor portscan: \$INTERNAL 3 5 portscan.log\npreprocessor portscan-ignorehosts: \$DNS_SERVERS\n\n";
print f "include %snortroot/etc/vision.conf\n";
close(f);'

### Change ownership of log directory.
chown -R snort.snort %snortroot/log


%preun
/etc/init.d/snortd stop
if [ $1 = 0 ] ; then
/sbin/chkconfig --del snortd
fi

%postun
#only if we are removing, not upgrading..
if [ $1 = 0 ] ; then
userdel snort 2> /dev/null || true
groupdel snort 2> /dev/null || true
fi

%files
%defattr(-,root,root)
%doc AUTHORS BUGS COPYING CREDITS ChangeLog INSTALL NEWS README* USAGE
%doc $RPM_SOURCE_DIR/snort.conf.dist
%attr(755,root,root)       %snortroot/sbin/*
%attr(755,root,root) 	   %snortroot/bin/*
%attr(750,root,wheel)  %dir %snortroot/log
%attr(750,root,wheel)  %dir %snortroot/log/archive
%attr(640,root,wheel) %config %snortroot/etc/*-lib
%attr(640,root,wheel) %config(noreplace)     %snortroot/etc/snort.conf
%attr(640,root,wheel) %config(noreplace)     %snortroot/etc/vision.conf
%attr(750,root,root)   /etc/init.d/snortd

%changelog
* Thu Mar 29 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.7
  - Disabled starting by default.


* Wed Mar 28 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.6
  - Rebuild against libmysqlclient.so.10


* Tue Mar 27 2001 Ryan W. Maple <ryan@guardiandigital.com>
  - Updated initscript.


* Wed Feb 28 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.[23]
  - We are now using the whitehats.com ruleset.
  - Fixed a bug in the initscript (log should be relatitve to chroot).
  - defrag preprocessor?
  - stream preprocessor?


* Mon Feb 05 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.1
  - Moved the package into production (Release change).
  - Took out all the rc.d stuff.
  - Modified chkconfig line to only run snort in runlevel 3.
  - Put man pages in %{_mandir}.  They were going in the chroot.
  - Changed initscript to stop using rc.d.
  - Changed initscript to use '/var/chroot/snort' for SNORTHOME.


* Mon Jan 15 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 7
  - Fixed the post-install perl script to get ip/dns/etc.

* Sun Jan 14 2001 Dave Wreski <dave@linuxsecurity.com>
- added snortroot to define where snort will be installed
- added -t chroot option
- all snort files (except docs) now live in snortroot
- move snort libs to seperate tarball

* Sat Jan 06 2001 Wim Vandersmissen <wim@bofh.be>
- Updated to version 1.7
- Some minor changes to snort.conf (uses default ruleset instead of 
  vision rules)

* Tue Jul 25 2000 Wim Vandersmissen <wim@bofh.st>
- Added some checks to find out if we're upgrading or removing the package

* Sat Jul 22 2000 Wim Vandersmissen <wim@bofh.st>
- Updated to version 1.6.3
- Fixed the user/group stuff (moved to %post)
- Added userdel/groupdel to %postun
- Automagically adds the right IP, nameservers to /etc/snort/rules.base

* Sat Jul 08 2000 Dave Wreski <dave@linuxsecurity.com>
- Updated to version 1.6.2
- Removed references to xntpd
- Fixed minor problems with snortd init script

* Fri Jul 07 2000 Dave Wreski <dave@linuxsecurity.com>
- Updated to version 1.6.1
- Added user/group snort

* Sat Jun 10 2000 Dave Wreski <dave@linuxsecurity.com>
- Added snort init.d script (snortd)
- Added Dave Dittrich's snort rules header file (ruiles.base)
- Added Dave Dittrich's wget rules fetch script (check-snort)
- Fixed permissions on /var/log/snort
- Created /var/log/snort/archive for archival of snort logs
- Added post/preun to add/remove snortd to/from rc?.d directories
- Defined configuration files as %config

* Tue Mar 28 2000 William Stearns <wstearns@pobox.com>
- Quick update to 1.6.
- Sanity checks before doing rm-rf in install and clean

* Fri Dec 10 1999 Henri Gomez <gomez@slib.fr>
- 1.5-0 Initial RPM release
